@@ -27,7 +27,6 @@ SDL_Renderer *mrc = NULL; /* main window render context, got only one */
 
 MainWindow::MainWindow(const char *title, int _w, int _h, int _full)
 {
-	int flags = 0;
 	if (_w <= 0 || _h <= 0) { /* no width or height, use desktop setting */
 		SDL_DisplayMode mode;
 		SDL_GetCurrentDisplayMode(0,&mode);
@@ -35,16 +34,19 @@ MainWindow::MainWindow(const char *title, int _w, int _h, int _full)
 		_h = mode.h;
 		_full = 1;
 	}
-	if (_full)
-		flags = SDL_WINDOW_FULLSCREEN;
 	w = _w;
 	h = _h;
 	/* TEST  w = 1600; h = 1200; flags = 0; */
 	Geom::sw = w;
 	Geom::sh = h;
 	_loginfo("Creating main window with %dx%d, fullscreen=%d\n",w,h,_full);
-	if( (mw = SDL_CreateWindow(title, SDL_WINDOWPOS_CENTERED,
-				SDL_WINDOWPOS_CENTERED, w, h, flags)) == NULL)
+ 	if (_full) {
+		mw = SDL_CreateWindow(title, 0,0,0,0,0);
+		SDL_SetWindowFullscreen(mw, SDL_WINDOW_FULLSCREEN_DESKTOP);
+	} else
+		mw = SDL_CreateWindow(title, SDL_WINDOWPOS_CENTERED,
+					SDL_WINDOWPOS_CENTERED, w, h, 0);
+	if(mw == NULL)
 		_logsdlerr();
 	if ((mr = SDL_CreateRenderer(mw, -1, SDL_RENDERER_ACCELERATED)) == NULL)
 		_logsdlerr();
@@ -94,6 +96,13 @@ int Image::create(int w, int h)
 	return 1;
 }
 
+/* Create texture from pixels in current render target. This only works
+ * if the render target has not been yet presented with SDL_RenderPresent()
+ * as otherwise the double buffer is flipped and we get the old contents.
+ * So the way to go is: build the render target, call this function, then
+ * render the present target and copy this image before a new
+ * SDL_RenderPresent().
+ */
 int Image::createFromScreen()
 {
 	int w, h;
@@ -773,23 +782,28 @@ int runConfirmDialog(Font &font, const string &caption)
 	img.copy();
 	font.setAlign(ALIGN_X_CENTER | ALIGN_Y_CENTER);
 	font.write(img.getWidth()/2, img.getHeight()/2, caption);
-	SDL_RenderPresent(mrc);
 
 	return waitForConfirmation();
 }
 
 /** Wait for confirmation key.
- * Returns 1 = confirmed, 0 = cancel, -1 = quit requested */
+ * Returns 1 = confirmed, 0 = cancel, -1 = quit requested.
+ * The render target must not have been presented yet otherwise we get
+ * the wrong buffer content for createFromScreen(). */
 int waitForConfirmation()
 {
 	int ret = 0;
 	bool done = false;
 	bool esc_pressed = false;
 	SDL_Event event;
+	Image sshot;
+
+	sshot.createFromScreen();
+	SDL_RenderPresent(mrc);
 
 	SDL_StartTextInput();
 	while (!done) {
-		if (SDL_WaitEvent(&event)) {
+		if (SDL_PollEvent(&event)) {
 			switch (event.type) {
 			case SDL_QUIT:
 				done = true;
@@ -820,6 +834,10 @@ int waitForConfirmation()
 				break;
 			}
 		}
+
+		SDL_Delay(20);
+		sshot.copy();
+		SDL_RenderPresent(mrc);
 		SDL_FlushEvent(SDL_MOUSEMOTION);
 	}
 	SDL_StopTextInput();
