@@ -52,9 +52,20 @@ View::View(Config &cfg, ClientGame &_cg)
 		for (auto &e : homeThemes)
 			themeNames.push_back(string("~")+e);
 	}
-	if ((uint)config.theme_id >= themeNames.size())
-		config.theme_id = 0;
 	config.theme_count = themeNames.size();
+	/* get theme id by name */
+	size_t pos = find(themeNames.begin(),themeNames.end(),config.theme)
+						- themeNames.begin();
+	if (pos < themeNames.size()) {
+		config.theme_id = (int)pos;
+		_loginfo("Theme %s has index %d\n",config.theme.c_str(),
+						config.theme_id);
+	} else {
+		config.theme_id = 0; /* fallback to first in list */
+		_loginfo("Theme %s not found, using theme %s at index %d\n",
+				config.theme.c_str(), themeNames[0].c_str(),
+				config.theme_id);
+	}
 
 	/* name for saved game */
 	if (string(CONFIGDIR) != ".")
@@ -234,8 +245,16 @@ void View::init(string t, uint r)
 	for (int i = 0; i < EDITWIDTH; i++)
 		theme.bricks.copy(1, 0, i*brickScreenWidth, 0);
 	SDL_SetRenderTarget(mrc, NULL);
-	warpIconX = (MAPWIDTH - 2)*brickScreenWidth;
-	warpIconY = (MAPHEIGHT - 1)*brickScreenHeight;
+
+	/* warp icon is different shape and position for old/new themes */
+	if (theme.oldTheme) {
+		warpIconX = brickScreenWidth*(MAPWIDTH-1) +
+					(brickScreenWidth - theme.warpIcon.getWidth())/2;
+		warpIconY = brickScreenHeight*MAPHEIGHT - theme.warpIcon.getHeight();
+	} else {
+		warpIconX = (MAPWIDTH - 2)*brickScreenWidth;
+		warpIconY = (MAPHEIGHT - 1)*brickScreenHeight;
+	}
 
 	/* clear viewport if not really needed */
 	if (viewport.w == ww && viewport.h == wh) {
@@ -252,6 +271,9 @@ View::~View()
 	mixer.close();
 	gamepad.close();
 
+	/* update theme name in config */
+	config.theme = themeNames[config.theme_id];
+
 	/* XXX fonts need to be killed before SDL/TTF_Quit otherwise they
 	 * segfault but attribute's dtors are called after ~View is finished */
 	theme.fSmall.free();
@@ -1351,7 +1373,7 @@ void View::createMenus()
 			_("Apply the above settings."),AID_APPLYTHEMEMODE));
 	mGraphics->add(new MenuItemSep());
 	mGraphics->add(new MenuItemList(_("Frame Limit"),
-			_("Maximum number of frames per second.\nBe careful: The higher the limit the more insensitive your mouse might become to slow movements if relative motion is used as program cycles get shorter.\n120 FPS should be a good value."),
+			_("Maximum number of frames per second.\nBe careful: The higher the limit the more insensitive your mouse might become to slow movements if relative motion is used as program cycles get shorter.\n60 FPS should be a good value."),
 			AID_NONE,config.fps,fpsLimitNames,3));
 	mGraphics->add(new MenuItemSep());
 	mGraphics->add(new MenuItemBack(mOptions));
